# Generated by roxygen2: do not edit by hand

S3method(identify,statcheck)
S3method(plot,statcheck)
S3method(summary,statcheck)
export(checkHTML)
export(checkHTMLdir)
export(checkPDF)
export(checkPDFdir)
export(checkdir)
export(statcheck)
export(statcheckReport)
export(trim)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotate)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,facet_grid)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(graphics,abline)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(graphics,plot.default)
importFrom(graphics,points)
importFrom(graphics,text)
importFrom(rlang,.data)
