# This file contains constants. These are mainly fixed variable names used
# throughout the package
# The logic of having a "constants" file, is that it now becomes straightforward
# to change a variable name, without having to go through all R scripts

# variables in final statcheck data frame
VAR_SOURCE <- "source"
VAR_TYPE <- "test_type"
VAR_DF1 <- "df1"
VAR_DF2 <- "df2"
VAR_TEST_COMPARISON <- "test_comp"
VAR_TEST_VALUE <- "test_value"
VAR_P_COMPARISON <- "p_comp"
VAR_REPORTED_P <- "reported_p"
VAR_COMPUTED_P <- "computed_p"
VAR_RAW <- "raw"
VAR_ERROR <- "error"
VAR_DEC_ERROR <- "decision_error"
VAR_1TAILTXT <- "one_tailed_in_txt"
VAR_APAFACTOR <- "apa_factor"

# additional variables to return
VAR_P_DEC <- "p_decimals"

# additional variables in summary function
VAR_NR_PVALUES <- "nr_p_values"
VAR_NR_ERRORS <- "nr_errors"
VAR_NR_DEC_ERRORS <- "nr_decision_errors"
