% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/checkHTMLdir.R, R/checkPDFdir.R, R/checkdir.R,
%   R/doc-checkdirs.R
\name{checkHTMLdir}
\alias{checkHTMLdir}
\alias{checkPDFdir}
\alias{checkdir}
\alias{checkdirs}
\title{Extract statistics from folders with PDF/HTML articles and recalculate 
p-values}
\usage{
checkHTMLdir(dir, subdir = TRUE, extension = TRUE, ...)

checkPDFdir(dir, subdir = TRUE, ...)

checkdir(dir, subdir = TRUE, ...)
}
\arguments{
\item{dir}{String indicating the directory to be used. If this is left empty, 
a window will pop up from which you can choose a directory.}

\item{subdir}{Logical. Indicates whether you also want to check subfolders. 
Defaults to TRUE}

\item{extension}{Logical. Indicates whether the HTML extension should be 
checked. Defaults to TRUE}

\item{...}{Arguments sent to \code{statcheck}.}
}
\value{
A statcheck data frame with the extracted statistics. See 
\code{\link{statcheck}} for details.
}
\description{
These functions search for NHST results in all PDF and/or HTML articles in a 
certain folder and send the extracted statistics to \code{statcheck}.
}
